{% extends "admin/base.html" %}

{% block title %}
  {% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} | {{ site_title|default:_('Django site admin') }}
{% endblock title %}

{% comment %}
  {% block branding %}
    <div id="site-name">
      <a href="{% url 'admin:index' %}">
        {{ site_header|default:_('Django administration') }}
      </a>
    </div>
    {% if user.is_anonymous %}
      {% include "admin/color_theme_toggle.html" %}
    {% endif %}
  {% endblock branding %}
{% endcomment %}

{% block nav-global %}
{% endblock nav-global%}
